Elekta Binary Logfiles — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# Elekta Binary Logfiles

A command line interface for the conversion of Elekta binary log files.

    usage: pymedphys trf [-h] {to-csv,detect,orchestrate} ...

## Positional Arguments

`trf`

  Possible choices: to-csv, detect, orchestrate

## Sub-commands

### to-csv

Converts `.trf` files to `.csv` table and header files.

    pymedphys trf to-csv [-h] filepaths [filepaths ...]

#### Positional Arguments

`filepaths`

  A list of `.trf` filepaths that you wish to convert to `.csv`. Use of the glob wildcard * is enabled, which means that running `pymedphys trf to-csv *.trf` will convert all logfiles in the current directory to csv files.

### detect

Attempts to detect trf encoding method.

    pymedphys trf detect [-h] filepath

#### Positional Arguments

`filepath`

  The filepath of a trf file.

### orchestrate

A command line interface for the management of trf files.

    pymedphys trf orchestrate [-h]